==> wcwidth-0.0.1.tar.gz: wcwidth-0.0.1/wcwidth/table_wide.py <==
# Generated: 2014-05-05T00:41:21.107471+00:00
# Source: EastAsianWidth-6.3.0.txt
# Date:  2013-02-05, 20:09:00 GMT [KW, LI]
WIDE_EASTASIAN = (
    (0x1100, 0x115f,),  # Hangul Choseong Kiyeok  ..Hangul Choseong Filler
    (0x2329, 0x232a,),  # Left-pointing Angle Brac..Right-pointing Angle Bra
    (0x2e80, 0x2e99,),  # Cjk Radical Repeat      ..Cjk Radical Rap
    (0x2e9b, 0x2ef3,),  # Cjk Radical Choke       ..Cjk Radical C-simplified
    (0x2f00, 0x2fd5,),  # Kangxi Radical One      ..Kangxi Radical Flute
    (0x2ff0, 0x2ffb,),  # Ideographic Description ..Ideographic Description
    (0x3000, 0x303e,),  # Ideographic Space       ..Ideographic Variation In
    (0x3041, 0x3096,),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
    (0x3099, 0x30ff,),  # Combining Katakana-hirag..Katakana Digraph Koto
    (0x3105, 0x312d,),  # Bopomofo Letter B       ..Bopomofo Letter Ih
    (0x3131, 0x318e,),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
    (0x3190, 0x31ba,),  # Ideographic Annotation L..Bopomofo Letter Zy
    (0x31c0, 0x31e3,),  # Cjk Stroke T            ..Cjk Stroke Q
    (0x31f0, 0x321e,),  # Katakana Letter Small Ku..Parenthesized Korean Cha
    (0x3220, 0x3247,),  # Parenthesized Ideograph ..Circled Ideograph Koto
    (0x3250, 0x32fe,),  # Partnership Sign        ..Circled Katakana Wo
    (0x3300, 0x4dbf,),  # Square Apaato           ..
    (0x4e00, 0xa48c,),  # Cjk Unified Ideograph-4e..Yi Syllable Yyr
    (0xa490, 0xa4c6,),  # Yi Radical Qot          ..Yi Radical Ke
    (0xa960, 0xa97c,),  # Hangul Choseong Tikeut-m..Hangul Choseong Ssangyeo
    (0xac00, 0xd7a3,),  # Hangul Syllable Ga      ..Hangul Syllable Hih
    (0xf900, 0xfaff,),  # Cjk Compatibility Ideogr..
    (0xfe10, 0xfe19,),  # Presentation Form For Ve..Presentation Form For Ve
    (0xfe30, 0xfe52,),  # Presentation Form For Ve..Small Full Stop
    (0xfe54, 0xfe66,),  # Small Semicolon         ..Small Equals Sign
    (0xfe68, 0xfe6b,),  # Small Reverse Solidus   ..Small Commercial At
    (0xff01, 0xff60,),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
    (0xffe0, 0xffe6,),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
    (0x1b000, 0x1b001,),  # Katakana Letter Archaic ..Hiragana Letter Archaic
    (0x1f200, 0x1f202,),  # Square Hiragana Hoka    ..Squared Katakana Sa
    (0x1f210, 0x1f23a,),  # Squared Cjk Unified Ideo..Squared Cjk Unified Ideo
    (0x1f240, 0x1f248,),  # Tortoise Shell Bracketed..Tortoise Shell Bracketed
    (0x1f250, 0x1f251,),  # Circled Ideograph Advant..Circled Ideograph Accept
    (0x20000, 0x2fffd,),  # Cjk Unified Ideograph-20..
    (0x30000, 0x3fffd,),  #                         ..
)

==> wcwidth-0.1.2.tar.gz: wcwidth-0.1.2/wcwidth/table_wide.py <==
# Generated: 2014-10-28T14:29:37.633514+00:00
# Source: EastAsianWidth-7.0.0.txt
# Date:  2014-02-28, 23:15:00 GMT [KW, LI]
WIDE_EASTASIAN = (
    (0x1100, 0x115f,),  # Hangul Choseong Kiyeok  ..Hangul Choseong Filler
    (0x2329, 0x232a,),  # Left-pointing Angle Brac..Right-pointing Angle Bra
    (0x2e80, 0x2e99,),  # Cjk Radical Repeat      ..Cjk Radical Rap
    (0x2e9b, 0x2ef3,),  # Cjk Radical Choke       ..Cjk Radical C-simplified
    (0x2f00, 0x2fd5,),  # Kangxi Radical One      ..Kangxi Radical Flute
    (0x2ff0, 0x2ffb,),  # Ideographic Description ..Ideographic Description
    (0x3000, 0x303e,),  # Ideographic Space       ..Ideographic Variation In
    (0x3041, 0x3096,),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
    (0x3099, 0x30ff,),  # Combining Katakana-hirag..Katakana Digraph Koto
    (0x3105, 0x312d,),  # Bopomofo Letter B       ..Bopomofo Letter Ih
    (0x3131, 0x318e,),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
    (0x3190, 0x31ba,),  # Ideographic Annotation L..Bopomofo Letter Zy
    (0x31c0, 0x31e3,),  # Cjk Stroke T            ..Cjk Stroke Q
    (0x31f0, 0x321e,),  # Katakana Letter Small Ku..Parenthesized Korean Cha
    (0x3220, 0x3247,),  # Parenthesized Ideograph ..Circled Ideograph Koto
    (0x3250, 0x32fe,),  # Partnership Sign        ..Circled Katakana Wo
    (0x3300, 0x4dbf,),  # Square Apaato           ..
    (0x4e00, 0xa48c,),  # Cjk Unified Ideograph-4e..Yi Syllable Yyr
    (0xa490, 0xa4c6,),  # Yi Radical Qot          ..Yi Radical Ke
    (0xa960, 0xa97c,),  # Hangul Choseong Tikeut-m..Hangul Choseong Ssangyeo
    (0xac00, 0xd7a3,),  # Hangul Syllable Ga      ..Hangul Syllable Hih
    (0xf900, 0xfaff,),  # Cjk Compatibility Ideogr..
    (0xfe10, 0xfe19,),  # Presentation Form For Ve..Presentation Form For Ve
    (0xfe30, 0xfe52,),  # Presentation Form For Ve..Small Full Stop
    (0xfe54, 0xfe66,),  # Small Semicolon         ..Small Equals Sign
    (0xfe68, 0xfe6b,),  # Small Reverse Solidus   ..Small Commercial At
    (0xff01, 0xff60,),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
    (0xffe0, 0xffe6,),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
    (0x1b000, 0x1b001,),  # Katakana Letter Archaic ..Hiragana Letter Archaic
    (0x1f200, 0x1f202,),  # Square Hiragana Hoka    ..Squared Katakana Sa
    (0x1f210, 0x1f23a,),  # Squared Cjk Unified Ideo..Squared Cjk Unified Ideo
    (0x1f240, 0x1f248,),  # Tortoise Shell Bracketed..Tortoise Shell Bracketed
    (0x1f250, 0x1f251,),  # Circled Ideograph Advant..Circled Ideograph Accept
    (0x20000, 0x2fffd,),  # Cjk Unified Ideograph-20..
    (0x30000, 0x3fffd,),  # (nil)                   ..
)
